======================
 zope.contentprovider
======================

.. image:: https://img.shields.io/pypi/v/zope.contentprovider.svg
        :target: https://pypi.python.org/pypi/zope.contentprovider/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.contentprovider.svg
        :target: https://pypi.org/project/zope.contentprovider/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.contentprovider/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.contentprovider/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.contentprovider/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.contentprovider?branch=master

.. image:: https://readthedocs.org/projects/zopecontentprovider/badge/?version=latest
        :target: https://zopecontentprovider.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

This package provides a framework to develop componentized Web GUI
applications. Instead of describing the content of a page using a single
template or static system of templates and METAL macros, content provider
objects are dynamically looked up based on the setup/configuration of the
application.

Detailed documentation is available at https://zopecontentprovider.readthedocs.io
